package jp.co.isid.elportal.fileconvert.command.process;

import java.io.IOException;
import java.util.List;
import java.util.Timer;

import jp.co.isid.elportal.base.log.Logger;

/**
 * プロセス管理クラス
 *
 *
 */
public class ProcessExecuter {

    /** コマンド実行引数 **/
    private List<String> _parameters;
    /** タイムアウト時間 **/
    private static final int TIME_OUT_MILISECOND = 60 * 1000;

    /**
     * コンストラクタ
     *
     * @param lstParameter ImageMagicを実行するための、プログラム名と引数のリスト
     *
     */
    public ProcessExecuter(List<String> lstParameter) {
        _parameters = lstParameter;
    }

    /**
     * Jpegファイルを生成するプロセス(ImageMagic)を実行します。
     *
     * @return int ステータスコード。正常終了時は0を返します。
     * @throws IOException エラー発生時
     *
     */
    public int execute() throws IOException {
        ProcessBuilder pb = new ProcessBuilder(_parameters);
        Process p = pb.start();

        ProcessDestroyer task = new ProcessDestroyer(p);
        Timer timer = new Timer("ProcessDestroyerTimer");
        timer.schedule(task, TIME_OUT_MILISECOND);

        while (true) {
            try {
                // プロセスの終了待ち
                p.waitFor();
                break;
            } catch (InterruptedException e) {
                Logger.error("割り込みが発生しました。");
                //waitFor()はInterruptedExceptionが発生する可能性あり。
                //基本無視。
            }
        }

        //タイマーのキャンセル（必須）
        timer.cancel();
        return p.exitValue();
    }
}
