package jp.co.isid.elportal.fileconvert.service;

/**
 *
 * 入力値チェック例外
 *
 */
public class InputCheckException extends Exception {

	/** serialVersionUID */
	private static final long serialVersionUID = -1605240888682621464L;

	/** エラーコード */
	private final String _errorCode;
	/** 備考 */
	private final String[] _args;

	/**
	 * メッセージ、エラーコードを指定してインスタンスを生成します。
	 *
	 * @param message メッセージ
	 * @param errorCode エラーコード
	 */
	public InputCheckException(String message, String errorCode) {
		super(message);
		_errorCode = errorCode;
		_args = new String[0];
	}

	/**
	 * メッセージ、エラーコード、備考を指定してインスタンスを生成します。
	 *
	 * @param message メッセージ
	 * @param errorCode エラーコード
	 * @param args 備考
	 */
	public InputCheckException(String message, String errorCode, String... args) {
		super(message);
		_errorCode = errorCode;
		_args = args;
	}

	/**
	 * エラーコードを返します。
	 *
	 * @return エラーコード
	 */
	public final String getErrorCode() {
		return _errorCode;
	}

	/**
	 * 備考を返します。
	 *
	 * @return 備考
	 */
	public final String[] getArguments() {
		return _args;
	}

}
