package jp.co.isid.elportal.fileconvert.service;

import java.util.ArrayList;
import java.util.List;

import jp.co.isid.soa.framework.service.exception.ExceptionHandler;
import jp.co.isid.soa.framework.service.exception.ServiceException;
import jp.co.isid.soa.framework.service.exception.ServiceExceptionAttribute;


/**
 *
 * 入力値チェック例外を共通サービス例外に変換するクラス。
 *
 */
public final class InputCheckExceptionHandler {

	/**
	 * ユーティリティクラスの為、インスタンス生成禁止。
	 */
	private InputCheckExceptionHandler() {
	}

	/**
	 * ThrowableをServiceExceptionとしてthrowします。</br>
	 * また、入力値チェック例外の場合のみ、詳細な情報を設定しthrowします。
	 *
	 * @param t Throwable 変換対象の
	 * @throws ServiceException 必ずこの型でthrowされる。
	 */
	public static void throwServiceException(InputCheckException t) throws ServiceException {
		List<ServiceExceptionAttribute> attrList = new ArrayList<ServiceExceptionAttribute>();
		for (int i = 0; i < (t).getArguments().length; i++) {
			ServiceExceptionAttribute attr = new ServiceExceptionAttribute();
			attr.setKey("{" + i + "}");
			attr.setValue((t).getArguments()[i]);
			attrList.add(attr);
		}
		if (attrList.size() == 0) {
			ExceptionHandler.getInstance().handleException(
					t,
					(t).getErrorCode()
			);
		} else {
			ExceptionHandler.getInstance().handleException(
					t,
					(t).getErrorCode(),
					attrList.toArray(new ServiceExceptionAttribute[0])
			);
		}
	}
}
