package jp.co.isid.elportal.fileconvert.util;

import java.io.File;

import jp.co.isid.elportal.base.cifs.CifsAccessor;
import jp.co.isid.elportal.base.cifs.CifsAccessorFactory;
import jp.co.isid.elportal.base.cifs.exception.CifsApplicationException;
import jp.co.isid.elportal.fileconvert.consts.CommonConstants.CifsType;

/**
 * <p>ファイル操作ユーティリティクラス</p>
 *
 *
 */
public final class FileUtil {

    /**
     * コンストラクター（private）
     */
    private FileUtil() {

    }

    /**
     * ファイルのフルパスを取得します
     *
     * @param path 相対ファイルパス
     * @param type CIFS接続タイプ
     * @return String ファイルのフルパス
     * @throws CifsApplicationException ファイルがなかった場合
     */
    public static String getFullPath(String path, CifsType type) throws CifsApplicationException {
        CifsAccessor cifs = CifsAccessorFactory.getInstance().getAccessor(type.getName());
        return cifs.getPath(path);
    }

    /**
     * <p>ファイルの相対パスを生成します</p>
     *
     * @param fileName ファイル名
     * @param extension 拡張子
     * @return String ファイルの相対パス
     */
    public static String getAbsolutePath(String fileName, String extension) {
        // ファイル名の先頭6文字でディレクトリ作成（YYYYMM）
        int length = StringUtil.length(fileName);
        if (length < 6) {
            return fileName;
        }

        return fileName.substring(0, 6) + File.separator + createFileName(fileName, extension);
    }

    /**
     * <p>ファイル名を生成します</p>
     *
     * @param fileName ファイル名
     * @param extension 拡張子
     * @return String ファイル名
     */
    private static String createFileName(String fileName, String extension) {
        int index = fileName.lastIndexOf(".");
        if (index < 0) {
            return fileName + "." + extension;
        }

        return fileName.substring(0, index + 1) + extension;
    }
}